==> uuid-creator-4.0.0-sources.jar: com/github/f4b6a3/uuid/codec/base/Base58FlickrCodec.java <==
/*
 * MIT License
 * 
 * Copyright (c) 2018-2021 Fabio Lima
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.github.f4b6a3.uuid.codec.base;

/**
 * Codec for base-58.
 * 
 * It is case SENSITIVE.
 * 
 * It encodes using remainder operator (modulus).
 * 
 * The alphabet for this codec is the same used in Flickr.
 * 
 * Read: https://www.flickr.com/groups/api/discuss/72157616713786392/
 */
public final class Base58FlickrCodec extends BaseNCodec {

	/**
	 * A shared immutable instance.
	 */
	public static final Base58FlickrCodec INSTANCE = new Base58FlickrCodec();

	public Base58FlickrCodec() {
		super(BaseN.BASE_58_FLICKR);
	}
}

==> uuid-creator-4.2.1-sources.jar: com/github/f4b6a3/uuid/codec/base/Base58FlickrCodec.java <==
/*
 * MIT License
 * 
 * Copyright (c) 2018-2021 Fabio Lima
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.github.f4b6a3.uuid.codec.base;

/**
 * Codec for base-58.
 * 
 * It is case SENSITIVE.
 * 
 * It encodes using remainder operator (modulus).
 * 
 * The alphabet for this codec is the same used in Flickr.
 * 
 * Read: https://www.flickr.com/groups/api/discuss/72157616713786392/
 */
public final class Base58FlickrCodec extends BaseNCodec {

	private static final BaseN BASE_N = new BaseN("123456789abcdefghijkmnopqrstuvwxyzABCDEFGHJKLMNPQRSTUVWXYZ");

	/**
	 * A shared immutable instance.
	 */
	public static final Base58FlickrCodec INSTANCE = new Base58FlickrCodec();

	public Base58FlickrCodec() {
		super(BASE_N);
	}
}
